import React, { useEffect, useRef, useState } from "react";
import {
    AddIcon,
    RemoveIcon,
    ResizeHeightIcon,
} from "../../../../../icons/ExportCommonIcons";
import LabledDropdown from "../../../../../ui/inputs/LabledDropdown";
import RenameInput from "../../../../../ui/inputs/RenameInput";
import { handleResize } from "../../../../../../functions/handleResizePannel";
import { useProductStore } from "../../../../../../store/simulation/useProductStore";
import { useSelectedProduct } from "../../../../../../store/simulation/useSimulationStore";

type TriggerProps = {
    selectedPointData?: PointsScheme | undefined;
    type?: 'Conveyor' | 'Vehicle' | 'RoboticArm' | 'Machine' | 'StorageUnit';
};

const Trigger = ({ selectedPointData, type }: TriggerProps) => {
    const [currentAction, setCurrentAction] = useState<string | undefined>();
    const { selectedProduct } = useSelectedProduct();
    const { getActionByUuid } = useProductStore();
    const [triggers, setTriggers] = useState<TriggerSchema[]>([]);
    const [selectedTrigger, setSelectedTrigger] = useState<TriggerSchema | undefined>();
    const [activeOption, setActiveOption] = useState("onComplete");
    const triggersContainerRef = useRef<HTMLDivElement>(null);

    useEffect(() => {
        if (!selectedPointData) return;
        if (type === 'Conveyor' || type === 'Vehicle' || type === 'Machine' || type === 'StorageUnit') {
            setCurrentAction((selectedPointData as ConveyorPointSchema).action.actionUuid);
        }
    }, [selectedPointData]);

    useEffect(() => {
        if (!currentAction || !selectedProduct) return;
        const action = getActionByUuid(selectedProduct.productId, currentAction);
        setTriggers(action?.triggers || []);
        setSelectedTrigger(action?.triggers[0] || undefined);
    }, [currentAction, selectedProduct]);

    const addTrigger = (): void => {
    };

    const removeTrigger = (triggerUuid: string): void => {
    };

    const triggeredModel = selectedTrigger?.triggeredAsset?.triggeredModel || { modelName: "Select Model", modelUuid: "" };
    const triggeredPoint = selectedTrigger?.triggeredAsset?.triggeredPoint || { pointName: "Select Point", pointUuid: "" };
    const triggeredAction = selectedTrigger?.triggeredAsset?.triggeredAction || { actionName: "Select Action", actionUuid: "" };

    return (
        <div className="trigger-wrapper">
            <div className="header">
                <div className="title">Trigger</div>
                <button
                    className="add-button"
                    onClick={addTrigger}
                    style={{ cursor: "pointer" }}
                >
                    <AddIcon /> Add
                </button>
            </div>
            <div className="trigger-list">
                <div
                    className="lists-main-container"
                    ref={triggersContainerRef}
                    style={{ height: "120px" }}
                >
                    <div className="list-container">
                        {triggers.map((trigger) => (
                            <div
                                key={trigger.triggerUuid}
                                className={`list-item ${selectedTrigger?.triggerUuid === trigger.triggerUuid ? "active" : ""}`}
                                onClick={() => setSelectedTrigger(trigger)}
                            >
                                <button className="value" onClick={() => { }}>
                                    <RenameInput value={trigger.triggerName} onRename={() => { }} />
                                </button>
                                {triggers.length > 1 && (
                                    <button
                                        className="remove-button"
                                        onClick={() => removeTrigger(trigger.triggerUuid)}
                                    >
                                        <RemoveIcon />
                                    </button>
                                )}
                            </div>
                        ))}
                    </div>
                    <button
                        className="resize-icon"
                        id="action-resize"
                        onMouseDown={(e: any) => handleResize(e, triggersContainerRef)}
                    >
                        <ResizeHeightIcon />
                    </button>
                </div>
                <div className="trigger-item">
                    <div className="trigger-name">{selectedTrigger?.triggerName}</div>
                    <LabledDropdown
                        label="Trigger Type"
                        defaultOption={activeOption}
                        options={["onComplete", "onStart", "onStop", "delay"]}
                        onSelect={(option) => setActiveOption(option)}
                    />
                    <div className="trigger-options">
                        <LabledDropdown
                            label="Triggered Object"
                            defaultOption={triggeredModel.modelName}
                            options={[]}
                            onSelect={(option) => { }}
                        />
                        <LabledDropdown
                            label="Triggered Point"
                            defaultOption={triggeredPoint.pointName}
                            options={[]}
                            onSelect={(option) => { }}
                        />
                        <LabledDropdown
                            label="Triggered Action"
                            defaultOption={triggeredAction.actionName}
                            options={[]}
                            onSelect={(option) => { }}
                        />
                    </div>
                </div>
            </div>
        </div>
    );
};

export default Trigger;
